//+------------------------------------------------------------------+
//|                                            StochRSIHistogram.mq4 |
//|                                    Copyright  2008, Robert Hill |
//|                                                                  |
//| Combines Stochastics and RSI in a histogram                      |
//+------------------------------------------------------------------+
#property copyright "Copyright  2008, Robert Hill"

#property indicator_separate_window
#property indicator_buffers 3
#property indicator_color1 Green //uptrend
#property indicator_width1 2  
#property indicator_color2 IndianRed  //downtrend
#property indicator_width2 2  
#property indicator_color3 DarkGreen // First Stochastic line
#property indicator_width3 2
#property indicator_levelcolor MediumOrchid  

extern int    KPeriod       = 14;
extern int    DPeriod       = 3;
extern int    SlowingPeriod = 3;
extern int    RSIPeriod     = 14;
extern double Uplevel       = 15;
extern double Dnlevel       = -15;
extern string note             = "turn on Alert = true; turn off = false";
extern bool   alertsOn         = true;
extern bool   alertsOnCurrent  = true;
extern bool   alertsMessage    = true;
extern bool   alertsSound      = true;
extern bool   alertsEmail      = false;
extern string soundfile        = "alert2.wav";

double upB[];
double loB[];
double Stoch1[];
double trend[];
//+------------------------------------------------------------------+
int init() {

   IndicatorBuffers(4);
   
   SetIndexStyle(0,DRAW_HISTOGRAM,STYLE_SOLID);
   SetIndexBuffer(0,upB);
   SetIndexEmptyValue(0,EMPTY_VALUE);
   
   SetIndexStyle(1,DRAW_HISTOGRAM,STYLE_SOLID); //downtrend
   SetIndexBuffer(1,loB);
   SetIndexEmptyValue(1,EMPTY_VALUE);

   SetIndexStyle(2,DRAW_LINE);
   SetIndexBuffer(2,Stoch1);
   SetIndexBuffer(3,trend);
   SetLevelValue(0,Uplevel);
   SetLevelValue(1,Dnlevel);

   IndicatorShortName("Stoch" + "(" + KPeriod + "," + DPeriod + "," + SlowingPeriod + ")" + " - RSI" + "(" + RSIPeriod + ") Histogram" );

   return(0);
}
//+------------------------------------------------------------------+
int deinit() {
   
   
}
//+------------------------------------------------------------------+
int start() {

   int counted_bars=IndicatorCounted();
   int shift,limit;
   double Stoch, RSI;
   
   if (counted_bars<0) return(-1);
   if (counted_bars>0) counted_bars--;
  
   limit=Bars-31;
   if(counted_bars>=0) limit=Bars-counted_bars+2;

   for (shift=limit;shift>=0;shift--)   {
      
      upB[shift] = 0;
      loB[shift] = 0;
      Stoch1[shift] = 0;
      Stoch=iStochastic(NULL,0,KPeriod,DPeriod,SlowingPeriod,MODE_SMA,0,MODE_MAIN,shift);      
      RSI = iRSI(NULL, 0, RSIPeriod, PRICE_CLOSE, shift);
      Stoch1[shift]=Stoch + RSI - 100;      
      if(Stoch1[shift]>0) 
      {
         upB[shift]=Stoch1[shift];
         
      } else if (Stoch1[shift]<0){
      
         loB[shift]=Stoch1[shift];
         
      }
      trend[shift] = trend[shift+1];
      if (Stoch1[shift] < Dnlevel) trend[shift] =-1;
      if (Stoch1[shift] > Uplevel) trend[shift] = 1;
   }
   
   //
   //
   //
   //
   //
      
   if (alertsOn)
   {
     if (alertsOnCurrent)
          int whichBar = 0;
     else     whichBar = 1;
     if (trend[whichBar] != trend[whichBar+1])
     if (trend[whichBar] == 1)
           doAlert("Buy");
     else  doAlert("Sell");       
   }
return(0);
}

//------------------------------------------------------------------
//
//------------------------------------------------------------------
//
//
//
//
//

void doAlert(string doWhat)
{
   static string   previousAlert="nothing";
   static datetime previousTime;
   string message;
   
      if (previousAlert != doWhat || previousTime != Time[0]) {
          previousAlert  = doWhat;
          previousTime   = Time[0];

          //
          //
          //
          //
          //

          message =  StringConcatenate(Symbol()," at ",TimeToStr(TimeLocal(),TIME_SECONDS)," StochRSIHistogram ",doWhat);
             if (alertsMessage) Alert(message);
             if (alertsEmail)   SendMail(StringConcatenate(Symbol()," StochRSIHistogram "),message);
             if (alertsSound)   PlaySound(soundfile);
      }
}